@@ -44,13 +44,13 @@
 #include <locale.h>
 #include <libintl.h>
 
-#include "config.h"
+#include "cameraconfig.h"
 #include "gviewencoder.h"
 #include "encoder.h"
 #include "stream_io.h"
 #include "gview.h"
 #include "camview.h"
-
+#include "load_libs.h"
 
 #if LIBAVUTIL_VER_AT_LEAST(52,2)
 #include <libavutil/channel_layout.h>
@@ -207,7 +207,7 @@ static void encoder_clean_video_ring_buffer()
  *
  * returns: none
  */
-void __attribute__ ((constructor)) gviewencoder_init()
+void /*__attribute__ ((constructor)) */gviewencoder_init()
 {
 #if !LIBAVCODEC_VER_AT_LEAST(57,16)
 	fprintf(stderr, "ENCODER: Error - libavcodec version not supported (minimum 57.16)\n");
@@ -235,7 +235,7 @@ void __attribute__ ((constructor)) gviewencoder_init()
  *
  * returns: none
  */
-void __attribute__ ((destructor)) gviewencoder_fini()
+void /*__attribute__ ((destructor))*/ gviewencoder_fini()
 {
 	if(verbosity > 1)
 		printf("ENCODER: destructor function called\n");
@@ -417,10 +417,10 @@ static encoder_video_context_t *encoder_video_init(encoder_context_t *encoder_ct
 	 * find the video encoder
 	 *   try specific codec (by name)
 	 */
-	video_codec_data->codec = avcodec_find_encoder_by_name(video_defaults->codec_name);
+    video_codec_data->codec = getLoadLibsInstance()->m_avcodec_find_encoder_by_name(video_defaults->codec_name);
 	/*if it fails try any codec with matching AV_CODEC_ID*/
 	if(!video_codec_data->codec)
-		video_codec_data->codec = avcodec_find_encoder(video_defaults->codec_id);
+        video_codec_data->codec = getLoadLibsInstance()->m_avcodec_find_encoder(video_defaults->codec_id);
 
 	if(!video_codec_data->codec)
 	{
@@ -445,9 +445,9 @@ static encoder_video_context_t *encoder_video_init(encoder_context_t *encoder_ct
 		return (enc_video_ctx);
 	}
 
-	video_codec_data->codec_context = avcodec_alloc_context3(video_codec_data->codec);
+    video_codec_data->codec_context = getLoadLibsInstance()->m_avcodec_alloc_context3(video_codec_data->codec);
 
-	avcodec_get_context_defaults3 (
+    getLoadLibsInstance()->m_avcodec_get_context_defaults3 (
 			video_codec_data->codec_context,
 			video_codec_data->codec);
 
@@ -479,9 +479,9 @@ static encoder_video_context_t *encoder_video_init(encoder_context_t *encoder_ct
 	if( video_defaults->codec_id == AV_CODEC_ID_H264 && video_defaults->me_method > 4)
 		video_defaults->me_method = X264_ME_HEX;
 
-	av_dict_set_int(&video_codec_data->private_options, "motion-est", video_defaults->me_method, 0);
-	av_dict_set_int(&video_codec_data->private_options, "mpeg_quant", video_defaults->mpeg_quant, 0);
-	av_dict_set_int(&video_codec_data->private_options, "mepre", video_defaults->pre_me, 0);
+    getAvutil()->m_av_dict_set_int(&video_codec_data->private_options, "motion-est", video_defaults->me_method, 0);
+    getAvutil()->m_av_dict_set_int(&video_codec_data->private_options, "mpeg_quant", video_defaults->mpeg_quant, 0);
+    getAvutil()->m_av_dict_set_int(&video_codec_data->private_options, "mepre", video_defaults->pre_me, 0);
 
 
 	video_codec_data->codec_context->dia_size = video_defaults->dia;
@@ -530,23 +530,23 @@ static encoder_video_context_t *encoder_video_init(encoder_context_t *encoder_ct
         {
            video_codec_data->codec_context->me_range = 16;
            //av_dict_set(&video_codec_data->private_options, "rc_lookahead", "1", 0);
-           av_dict_set(&video_codec_data->private_options, "crf", "23", 0);
-           av_dict_set(&video_codec_data->private_options, "preset", "ultrafast", 0);
-           av_dict_set(&video_codec_data->private_options,"tune", "zerolatency", 0);
+           getAvutil()->m_av_dict_set(&video_codec_data->private_options, "crf", "23", 0);
+           getAvutil()->m_av_dict_set(&video_codec_data->private_options, "preset", "ultrafast", 0);
+           getAvutil()->m_av_dict_set(&video_codec_data->private_options,"tune", "zerolatency", 0);
         }
         break;
     case AV_CODEC_ID_HEVC:
         {
            video_codec_data->codec_context->me_range = 16;
-           av_dict_set(&video_codec_data->private_options, "crf", "28", 0);
-           av_dict_set(&video_codec_data->private_options, "preset", "ultrafast", 0);
+           getAvutil()->m_av_dict_set(&video_codec_data->private_options, "crf", "28", 0);
+           getAvutil()->m_av_dict_set(&video_codec_data->private_options, "preset", "ultrafast", 0);
         }
         break;
     case AV_CODEC_ID_VP8:
         {
-            av_dict_set(&video_codec_data->private_options, "quality", "good", 0);
-            av_dict_set(&video_codec_data->private_options, "cpu-used","-10",0);
-            av_dict_set(&video_codec_data->private_options, "speed","10",0);
+            getAvutil()->m_av_dict_set(&video_codec_data->private_options, "quality", "good", 0);
+            getAvutil()->m_av_dict_set(&video_codec_data->private_options, "cpu-used","-10",0);
+            getAvutil()->m_av_dict_set(&video_codec_data->private_options, "speed","10",0);
         }
         break;
     default:
@@ -555,7 +555,7 @@ static encoder_video_context_t *encoder_video_init(encoder_context_t *encoder_ct
 
 	int ret = 0;
 	/* open codec*/
-	if ((ret = avcodec_open2(
+    if ((ret = getLoadLibsInstance()->m_avcodec_open2(
 		video_codec_data->codec_context,
 		video_codec_data->codec,
 		&video_codec_data->private_options)) < 0)
@@ -584,7 +584,7 @@ static encoder_video_context_t *encoder_video_init(encoder_context_t *encoder_ct
 		return (enc_video_ctx);
 	}
 
-	video_codec_data->frame = av_frame_alloc();
+    video_codec_data->frame = getAvutil()->m_av_frame_alloc();
 
 	if(video_codec_data->frame == NULL)
 	{
@@ -593,7 +593,7 @@ static encoder_video_context_t *encoder_video_init(encoder_context_t *encoder_ct
 	}
 	video_codec_data->frame->pts = 0;
 
-	video_codec_data->outpkt = av_packet_alloc();
+    video_codec_data->outpkt = getLoadLibsInstance()->m_av_packet_alloc();
 
 	if(video_codec_data->outpkt == NULL)
 	{
@@ -699,10 +699,10 @@ static encoder_audio_context_t *encoder_audio_init(encoder_context_t *encoder_ct
 	 * find the audio encoder
 	 *   try specific codec (by name)
 	 */
-	audio_codec_data->codec = avcodec_find_encoder_by_name(audio_defaults->codec_name);
+    audio_codec_data->codec = getLoadLibsInstance()->m_avcodec_find_encoder_by_name(audio_defaults->codec_name);
 	/*if it fails try any codec with matching AV_CODEC_ID*/
 	if(!audio_codec_data->codec)
-		audio_codec_data->codec = avcodec_find_encoder(audio_defaults->codec_id);
+        audio_codec_data->codec = getLoadLibsInstance()->m_avcodec_find_encoder(audio_defaults->codec_id);
 
 	if(!audio_codec_data->codec)
 	{
@@ -713,8 +713,8 @@ static encoder_audio_context_t *encoder_audio_init(encoder_context_t *encoder_ct
 		return NULL;
 	}
 
-	audio_codec_data->codec_context = avcodec_alloc_context3(audio_codec_data->codec);
-	avcodec_get_context_defaults3 (audio_codec_data->codec_context, audio_codec_data->codec);
+    audio_codec_data->codec_context = getLoadLibsInstance()->m_avcodec_alloc_context3(audio_codec_data->codec);
+    getLoadLibsInstance()->m_avcodec_get_context_defaults3 (audio_codec_data->codec_context, audio_codec_data->codec);
 
 	if(audio_codec_data->codec_context == NULL)
 	{
@@ -837,7 +837,7 @@ static encoder_audio_context_t *encoder_audio_init(encoder_context_t *encoder_ct
 	audio_codec_data->codec_context->sample_fmt = audio_defaults->sample_format;
 
 	/* open codec*/
-	if (avcodec_open2(
+    if (getLoadLibsInstance()->m_avcodec_open2(
 		audio_codec_data->codec_context,
 		audio_codec_data->codec, NULL) < 0)
 	{
@@ -870,7 +870,7 @@ static encoder_audio_context_t *encoder_audio_init(encoder_context_t *encoder_ct
 		exit(-1);
 	}
 
-	audio_codec_data->frame = av_frame_alloc();
+    audio_codec_data->frame = getAvutil()->m_av_frame_alloc();
 
 	if(audio_codec_data->frame == NULL)
 	{
@@ -878,9 +878,9 @@ static encoder_audio_context_t *encoder_audio_init(encoder_context_t *encoder_ct
 		exit(-1);
 	}
 
-	av_frame_unref(audio_codec_data->frame);
+    getAvutil()->m_av_frame_unref(audio_codec_data->frame);
 
-	audio_codec_data->outpkt = av_packet_alloc();
+    audio_codec_data->outpkt = getLoadLibsInstance()->m_av_packet_alloc();
 
 	if(audio_codec_data->outpkt == NULL)
 	{
@@ -1499,12 +1499,12 @@ static int libav_encode(AVCodecContext *avctx, AVPacket *pkt, AVFrame *frame, in
 
 	if(frame)
     {
-		ret = avcodec_send_frame(avctx, frame);
+        ret = getLoadLibsInstance()->m_avcodec_send_frame(avctx, frame);
         if (ret < 0)
             return ret; //if (ret == AVERROR(EAGAIN)) //input buffer is full
     }
 
-  ret = avcodec_receive_packet(avctx, pkt);
+  ret = getLoadLibsInstance()->m_avcodec_receive_packet(avctx, pkt);
   char str[50];
   sprintf(str,"avcode_receive_packet of ret=%d",ret);
   //cheese_print_log(str);
@@ -1608,7 +1608,7 @@ int encoder_encode_video(encoder_context_t *encoder_ctx, void *input_frame)
 	{
 		if(!enc_video_ctx->flushed_buffers)
 		{
-			avcodec_flush_buffers(video_codec_data->codec_context);
+            getLoadLibsInstance()->m_avcodec_flush_buffers(video_codec_data->codec_context);
 			enc_video_ctx->flushed_buffers = 1;
 		}
  	}
@@ -1664,13 +1664,13 @@ int encoder_encode_video(encoder_context_t *encoder_ctx, void *input_frame)
     	{
     		int i;
         	for (i = 0; i < pkt->side_data_elems; i++)
-        		av_free(pkt->side_data[i].data);
-        	av_freep(&pkt->side_data);
+                getAvutil()->m_av_free(pkt->side_data[i].data);
+            getAvutil()->m_av_freep(&pkt->side_data);
         	pkt->side_data_elems = 0;
     	}
     	outsize = pkt->size;
 
-			av_packet_unref(pkt);
+            getLoadLibsInstance()->m_av_packet_unref(pkt);
     }
 
 	if(enc_video_ctx->flush_delayed_frames && ((outsize == 0) || !got_packet))
@@ -1728,7 +1728,7 @@ int encoder_encode_audio(encoder_context_t *encoder_ctx, void *audio_data)
 		if(!enc_audio_ctx->flushed_buffers)
 		{
 			if(audio_codec_data)
-				avcodec_flush_buffers(audio_codec_data->codec_context);
+                getLoadLibsInstance()->m_avcodec_flush_buffers(audio_codec_data->codec_context);
 			enc_audio_ctx->flushed_buffers = 1;
 		}
  	}
@@ -1747,7 +1747,7 @@ int encoder_encode_audio(encoder_context_t *encoder_ctx, void *audio_data)
 
 		int align = 0;
 
-		int buffer_size = av_samples_get_buffer_size(
+        int buffer_size = getAvutil()->m_av_samples_get_buffer_size(
 			NULL,
 			audio_codec_data->codec_context->channels,
 			audio_codec_data->frame->nb_samples,
@@ -1767,7 +1767,7 @@ int encoder_encode_audio(encoder_context_t *encoder_ctx, void *audio_data)
 
 
 		/*set the data pointers in frame*/
-		ret = avcodec_fill_audio_frame(
+        ret = getLoadLibsInstance()->m_avcodec_fill_audio_frame(
 			audio_codec_data->frame,
 			audio_codec_data->codec_context->channels,
 			audio_codec_data->codec_context->sample_fmt,
@@ -1836,11 +1836,11 @@ int encoder_encode_audio(encoder_context_t *encoder_ctx, void *audio_data)
 		//ff_packet_free_side_data(&pkt);
 		if (audio_codec_data->frame &&
 			audio_codec_data->frame->extended_data != audio_codec_data->frame->data)
-			av_freep(audio_codec_data->frame->extended_data);
+            getAvutil()->m_av_freep(audio_codec_data->frame->extended_data);
 
 		outsize = pkt->size;
 		
-		av_packet_unref(pkt);
+        getLoadLibsInstance()->m_av_packet_unref(pkt);
 	}
 
 	last_audio_pts = enc_audio_ctx->pts;
@@ -1890,20 +1890,20 @@ void encoder_close(encoder_context_t *encoder_ctx)
 		{
 			if(!(enc_video_ctx->flushed_buffers))
 			{
-				avcodec_flush_buffers(video_codec_data->codec_context);
+                getLoadLibsInstance()->m_avcodec_flush_buffers(video_codec_data->codec_context);
 				enc_video_ctx->flushed_buffers = 1;
 			}
 
-            avcodec_close(video_codec_data->codec_context);
+            getLoadLibsInstance()->m_avcodec_close(video_codec_data->codec_context);
                 free(video_codec_data->codec_context);
 
-			av_dict_free(&(video_codec_data->private_options));
+            getAvutil()->m_av_dict_free(&(video_codec_data->private_options));
 
 			if(video_codec_data->frame)
-				av_frame_free(&video_codec_data->frame);
+                getAvutil()->m_av_frame_free(&video_codec_data->frame);
 
 			if(video_codec_data->outpkt)
-				av_packet_free(&video_codec_data->outpkt);
+                getLoadLibsInstance()->m_av_packet_free(&video_codec_data->outpkt);
 
 			free(video_codec_data);
 		}
@@ -1926,16 +1926,16 @@ void encoder_close(encoder_context_t *encoder_ctx)
 		audio_codec_data = (encoder_codec_data_t *) enc_audio_ctx->codec_data;
 		if(audio_codec_data)
 		{
-			avcodec_flush_buffers(audio_codec_data->codec_context);
+            getLoadLibsInstance()->m_avcodec_flush_buffers(audio_codec_data->codec_context);
 
-			avcodec_close(audio_codec_data->codec_context);
+            getLoadLibsInstance()->m_avcodec_close(audio_codec_data->codec_context);
 			free(audio_codec_data->codec_context);
 
 			if(audio_codec_data->frame)
-				av_frame_free(&audio_codec_data->frame);
+                getAvutil()->m_av_frame_free(&audio_codec_data->frame);
 
 			if(audio_codec_data->outpkt)
-				av_packet_free(&audio_codec_data->outpkt);
+                getLoadLibsInstance()->m_av_packet_free(&audio_codec_data->outpkt);
 
 			free(audio_codec_data);
 		}
