@@ -36,8 +36,8 @@
 #include "frame_decoder.h"
 #include "jpeg_decoder.h"
 #include "colorspaces.h"
-#include "config.h"
-
+#include "cameraconfig.h"
+#include "load_libs.h"
 extern int verbosity;
 
 /*
@@ -175,9 +175,9 @@ int alloc_v4l2_frames(v4l2_dev_t *vd)
 		case V4L2_PIX_FMT_GREY:
 		case V4L2_PIX_FMT_Y10BPACK:
 	    case V4L2_PIX_FMT_Y16:
-#ifdef V4L2_PIX_FMT_Y16_BE
-		case V4L2_PIX_FMT_Y16_BE:
-#endif
+//#ifdef V4L2_PIX_FMT_Y16_BE
+//		case V4L2_PIX_FMT_Y16_BE:
+//#endif
 #ifdef V4L2_PIX_FMT_ABGR32
 		case V4L2_PIX_FMT_ABGR32:
 		case V4L2_PIX_FMT_XBGR32:
@@ -194,10 +194,10 @@ int alloc_v4l2_frames(v4l2_dev_t *vd)
 		case V4L2_PIX_FMT_ARGB555:
 		case V4L2_PIX_FMT_XRGB555:
 #endif
-#ifdef V4L2_PIX_FMT_ARGB555X
-		case V4L2_PIX_FMT_ARGB555X:
-		case V4L2_PIX_FMT_XRGB555X:
-#endif
+//#ifdef V4L2_PIX_FMT_ARGB555X
+//		case V4L2_PIX_FMT_ARGB555X:
+//		case V4L2_PIX_FMT_XRGB555X:
+//#endif
             framebuf_size =(size_t)  framesizeIn;
 			/*frame queue*/
 			for(i=0; i<vd->frame_queue_size; ++i)
@@ -510,23 +510,24 @@ static int demux_uvcH264(uint8_t *h264_data, uint8_t *buff, int size, __attribut
 	/*(in big endian)
 	 *includes payload size + header + 6 bytes(2 length + 4 payload size)
 	 */
-    uint16_t length = 0;
-    if (spl) {        
+	uint16_t length = 0;
+
+    if (spl) {
         length  = (uint16_t)((uint16_t) spl[0] << 8);
         length |= (uint16_t) spl[1];
         header = spl + 2;
     }
 	/*in litle endian*/
     uint16_t header_length = 0;
+
     if (header) {
         header_length = header[2];
         header_length |= header[3] << 8;
         spl = header + header_length;
     }
 	/*in litle endian*/
-	uint32_t payload_size = 0;
-
     if (spl) {
+        uint32_t payload_size = 0;
         payload_size =  ((uint32_t) spl[0]) << 0;
         payload_size |= ((uint32_t) spl[1]) << 8;
         payload_size |= ((uint32_t) spl[2]) << 16;
@@ -912,11 +913,11 @@ int decode_v4l2_frame(v4l2_dev_t *vd, v4l2_frame_buff_t *frame)
 	    case V4L2_PIX_FMT_Y16:
 			y16_to_yu12(frame->yuv_frame, frame->raw_frame, width, height);
 			break;
-#ifdef V4L2_PIX_FMT_Y16_BE
-		case V4L2_PIX_FMT_Y16_BE:
-			y16x_to_yu12(frame->yuv_frame, frame->raw_frame, width, height);
-			break;
-#endif
+//#ifdef V4L2_PIX_FMT_Y16_BE
+//		case V4L2_PIX_FMT_Y16_BE:
+//			y16x_to_yu12(frame->yuv_frame, frame->raw_frame, width, height);
+//			break;
+//#endif
 		case V4L2_PIX_FMT_SPCA501:
 			s501_to_yu12(frame->yuv_frame, frame->raw_frame, width, height);
 			break;
@@ -1053,14 +1054,14 @@ int libav_decode(AVCodecContext *avctx, AVFrame *frame, int *got_frame, AVPacket
 
 	if (pkt)
 	{
-			ret = avcodec_send_packet(avctx, pkt);
+            ret = getLoadLibsInstance()->m_avcodec_send_packet(avctx, pkt);
 			// In particular, we don't expect AVERROR(EAGAIN), because we read all
 			// decoded frames with avcodec_receive_frame() until done.
 			if (ret < 0)
 					return ret == AVERROR_EOF ? 0 : ret;
 	}
 
-	ret = avcodec_receive_frame(avctx, frame);
+    ret = getLoadLibsInstance()->m_avcodec_receive_frame(avctx, frame);
 	if (ret < 0 && ret != AVERROR(EAGAIN) && ret != AVERROR_EOF)
 			return ret;
 	if (ret >= 0)
@@ -1070,7 +1071,7 @@ int libav_decode(AVCodecContext *avctx, AVFrame *frame, int *got_frame, AVPacket
 
 #else
 
-	return avcodec_decode_video2(avctx, frame, got_frame, pkt);
+    return getLoadLibsInstance()->m_avcodec_decode_video2(avctx, frame, got_frame, pkt);
 
 #endif
 }
